## $Id: applicant.py 15123 2018-09-05 10:58:59Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from zope.interface import implementedBy
from waeup.kofa.applicants.applicant import ApplicantFactory
from waeup.kofa.utils.helpers import attrs_to_fields
from kofacustom.nigeria.applicants.applicant import NigeriaApplicant
from kofacustom.edopoly.applicants.interfaces import(
    ICustomApplicant, ICustomUGApplicantEdit, ICustomPGApplicantEdit, IPUTMEApplicantEdit)

class CustomApplicant(NigeriaApplicant):

    grok.implements(ICustomApplicant, ICustomUGApplicantEdit,
        ICustomPGApplicantEdit, IPUTMEApplicantEdit)
    grok.provides(ICustomApplicant)

    def admchecking_fee_paid(self):
        # We don't charge if admission checking fee is not set.
        session = str(self.__parent__.year)
        try:
            session_config = grok.getSite()['configuration'][session]
        except KeyError:
            return True
        if session_config.admchecking_fee == 0:
            return True
        for key in self.keys():
            ticket = self[key]
            if ticket.p_state == 'paid' and \
                ticket.p_category == 'admission_checking':
                return True
        return False

# Set all attributes of CustomApplicant required in ICustomApplicant as field
# properties. Doing this, we do not have to set initial attributes
# ourselves and as a bonus we get free validation when an attribute is
# set.
CustomApplicant = attrs_to_fields(CustomApplicant)

class CustomApplicantFactory(ApplicantFactory):
    """A factory for customized applicants.
    """

    def __call__(self, *args, **kw):
        return CustomApplicant()

    def getInterfaces(self):
        return implementedBy(CustomApplicant)
